@@ -1,15 +1,12 @@
-#!/usr/bin/env python
 # coding=utf-8
-# flake8: noqa
-# pylint: disable=missing-docstring
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
+"""lithium reducer"""
 
-from __future__ import absolute_import
-
-from .reducer import *  # pylint: disable=wildcard-import
+from .reducer import Lithium
+from .util import LithiumError
 
 __author__ = "Jesse Ruderman, Gary Kwong and Jesse Schwartzentruber"
-__maintainer__ = "Gary Kwong and Jesse Schwartzentruber"
+__maintainer__ = "Jesse Schwartzentruber"
