@@ -21,7 +21,7 @@ from pathlib import Path
 # Define struct that contains data from a process that has already ended.
 RunData = collections.namedtuple(
     "RunData",
-    "sta, return_code, msg, elapsedtime, killed, out, err",
+    "sta, return_code, msg, elapsedtime, killed, out, err, pid",
 )
 
 
@@ -61,7 +61,9 @@ def get_signal_name(signum, default="Unknown signal"):
     return default
 
 
-def timed_run(cmd_with_args, timeout, log_prefix=None, env=None, inp=None):
+def timed_run(
+    cmd_with_args, timeout, log_prefix=None, env=None, inp=None, preexec_fn=None
+):
     """If log_prefix is None, uses pipes instead of files for all output.
 
     Args:
@@ -70,6 +72,7 @@ def timed_run(cmd_with_args, timeout, log_prefix=None, env=None, inp=None):
         log_prefix (str): Prefix string of the log files
         env (dict): Environment for the command to be executed in
         inp (str): stdin to be passed to the command
+        preexec_fn (callable): called in child process after fork, prior to exec
 
     Raises:
         TypeError: Raises if input parameters are not of the desired types
@@ -85,6 +88,8 @@ def timed_run(cmd_with_args, timeout, log_prefix=None, env=None, inp=None):
         raise TypeError("timeout should be an int.")
     if log_prefix is not None and not isinstance(log_prefix, str):
         raise TypeError("log_prefix should be a string.")
+    if preexec_fn is not None and not hasattr(preexec_fn, "__call__"):
+        raise TypeError("preexec_fn should be callable.")
 
     prog = Path(cmd_with_args[0]).expanduser()
     cmd_with_args[0] = str(prog)
@@ -104,24 +109,28 @@ def timed_run(cmd_with_args, timeout, log_prefix=None, env=None, inp=None):
         child_stderr = open(log_prefix + "-err.txt", "wb")
 
     start_time = time.time()
+    child = subprocess.Popen(  # pylint: disable=subprocess-popen-preexec-fn
+        cmd_with_args,
+        env=env,
+        stderr=child_stderr,
+        stdout=child_stdout,
+        preexec_fn=preexec_fn,
+    )
     try:
-        result = subprocess.run(
-            cmd_with_args,
-            env=env,
+        stdout, stderr = child.communicate(
             input=inp,
-            stderr=child_stderr,
-            stdout=child_stdout,
             timeout=timeout,
         )
-    except subprocess.SubprocessError as exc:
-        if not isinstance(exc, subprocess.TimeoutExpired):
-            print("Tried to run:")
-            print("  %r" % cmd_with_args)
-            print("but got this error:")
-            print("  %s" % exc)
-            sys.exit(2)
+    except subprocess.TimeoutExpired:
+        child.kill()
+        stdout, stderr = child.communicate()
         sta = TIMED_OUT
-        result = exc  # needed for stdout/stderr
+    except Exception as exc:  # pylint: disable=broad-except
+        print("Tried to run:")
+        print("  %r" % cmd_with_args)
+        print("but got this error:")
+        print("  %s" % exc)
+        sys.exit(2)
     finally:
         if log_prefix is not None:
             child_stdout.close()
@@ -130,21 +139,21 @@ def timed_run(cmd_with_args, timeout, log_prefix=None, env=None, inp=None):
 
     if sta == TIMED_OUT:
         msg = "TIMED OUT"
-    elif result.returncode == 0:
+    elif child.returncode == 0:
         msg = "NORMAL"
         sta = NORMAL
-    elif 0 < result.returncode < 0x80000000:
-        msg = "ABNORMAL exit code " + str(result.returncode)
+    elif 0 < child.returncode < 0x80000000:
+        msg = "ABNORMAL exit code " + str(child.returncode)
         sta = ABNORMAL
     else:
         # return_code < 0 (or > 0x80000000 in Windows)
         # The program was terminated by a signal, which usually indicates a crash.
         # Mac/Linux only!
         # XXX: this doesn't work on Windows
-        if result.returncode < 0:
-            signum = -result.returncode
+        if child.returncode < 0:
+            signum = -child.returncode
         else:
-            signum = result.returncode
+            signum = child.returncode
         msg = "CRASHED signal %d (%s)" % (
             signum,
             get_signal_name(signum),
@@ -153,10 +162,11 @@ def timed_run(cmd_with_args, timeout, log_prefix=None, env=None, inp=None):
 
     return RunData(
         sta,
-        getattr(result, "returncode", None),  # result might be TimeoutExpired
+        child.returncode if sta != TIMED_OUT else None,
         msg,
         elapsed_time,
         sta == TIMED_OUT,
-        log_prefix + "-out.txt" if log_prefix is not None else result.stdout,
-        log_prefix + "-err.txt" if log_prefix is not None else result.stderr,
+        log_prefix + "-out.txt" if log_prefix is not None else stdout,
+        log_prefix + "-err.txt" if log_prefix is not None else stderr,
+        child.pid,
     )
